@@ -8,7 +8,6 @@ __copyright__ = '2015, Kovid Goyal <kovid at kovidgoyal.net>'
 
 import ssl, socket, select, os, traceback
 from io import BytesIO
-from Queue import Empty, Full
 from functools import partial
 
 from calibre import as_unicode
@@ -25,9 +24,11 @@ from calibre.utils.socket_inheritance import set_socket_inherit
 from calibre.utils.logging import ThreadSafeLog
 from calibre.utils.monotonic import monotonic
 from calibre.utils.mdns import get_external_ip
+from polyglot.builtins import iteritems
+from polyglot.queue import Empty, Full
 
 READ, WRITE, RDWR, WAIT = 'READ', 'WRITE', 'RDWR', 'WAIT'
-WAKEUP, JOB_DONE = bytes(bytearray(xrange(2)))
+WAKEUP, JOB_DONE = b'\0', b'\x01'
 IPPROTO_IPV6 = getattr(socket, "IPPROTO_IPV6", 41)
 
 
@@ -504,7 +505,7 @@ class ServerLoop(object):
         now = monotonic()
         read_needed, write_needed, readable, remove, close_needed = [], [], [], [], []
         has_ssl = self.ssl_context is not None
-        for s, conn in self.connection_map.iteritems():
+        for s, conn in iteritems(self.connection_map):
             if now - conn.last_activity > self.opts.timeout:
                 if conn.handle_timeout():
                     conn.last_activity = now
@@ -550,7 +551,7 @@ class ServerLoop(object):
                 # e.args[0]
                 if getattr(e, 'errno', e.args[0]) in socket_errors_eintr:
                     return
-                for s, conn in tuple(self.connection_map.iteritems()):
+                for s, conn in tuple(iteritems(self.connection_map)):
                     try:
                         select.select([s], [], [], 0)
                     except (select.error, socket.error) as e:
@@ -680,7 +681,7 @@ class ServerLoop(object):
                 self.socket = None
         except socket.error:
             pass
-        for s, conn in tuple(self.connection_map.iteritems()):
+        for s, conn in tuple(iteritems(self.connection_map)):
             self.close(s, conn)
         wait_till = monotonic() + self.opts.shutdown_timeout
         for pool in (self.plugin_pool, self.pool):
